==> pCon.configurator_Online_W-CF_8.4.1.tgz: package/modules/core/cmd/InsertDeleteElements.js <==
import { clone } from "../../utils/array";
import { UndoOperation } from "../mdl/SceneElement";
import { AbstractCommand } from "./AbstractCommand";
export class AbstractInsertDeleteElements extends AbstractCommand {
    constructor(pApp, pElements) {
        super(pApp);
        this.mElements = clone(pElements);
        this.mElementsDeleted = false;
        //store element and node parents
        this.mElementParents = new Array();
        this.mElementUndoData = new Array();
        this.mNodeParents = new Array();
        for (const tElement of this.mElements) {
            this.mElementParents.push(tElement.getParentElement());
            this.mElementUndoData.push(null);
            this.mNodeParents.push(tElement.node.parent);
        }
    }
    isAvailable() {
        return (this.mElements != null);
    }
    isUndoable() {
        return (true);
    }
    dispose() {
        if (this.mElementsDeleted) {
            for (const tElement of this.mElements)
                tElement.dispose();
        }
        this.mElements = undefined;
    }
    deleteElements() {
        const tModel = this.mApp.model;
        try {
            tModel.beginSelectionChange();
            //get delete undo data
            for (let i = 0; i < this.mElements.length; ++i) {
                this.mElementUndoData[i] = this.mElements[i].saveUndoData(UndoOperation.Delete);
            }
            //start change section for parents
            for (let i = 0; i < this.mElementParents.length; ++i) {
                const tParent = this.mElementParents[i];
                if (tParent != null)
                    tParent.beginChange();
            }
            for (let i = 0; i < this.mElements.length; ++i) {
                tModel.removeElement(this.mElements[i], true, false);
            }
        }
        finally {
            //end change section for parents
            for (let i = 0; i < this.mElementParents.length; ++i) {
                const tParent = this.mElementParents[i];
                if (tParent != null)
                    tParent.endChange();
            }
            tModel.endSelectionChange();
        }
        this.mElementsDeleted = true;
        this.mApp.viewer.requestRenderFrame();
    }
    insertElements(pAddToScene) {
        const tModel = this.mApp.model;
        try {
            //start change section for parents
            for (let i = 0; i < this.mElementParents.length; ++i) {
                const tParent = this.mElementParents[i];
                if (tParent != null)
                    tParent.beginChange();
            }
            for (let i = 0; i < this.mElements.length; ++i) {
                tModel.addElement(this.mElements[i], this.mNodeParents[i], pAddToScene);
            }
            //load delete undo data
            for (let i = 0; i < this.mElements.length; ++i) {
                if (this.mElementUndoData[i] != null)
                    this.mElements[i].loadUndoData(UndoOperation.Delete, this.mElementUndoData[i]);
            }
        }
        finally {
            //end change section for parents
            for (let i = 0; i < this.mElementParents.length; ++i) {
                const tParent = this.mElementParents[i];
                if (tParent != null)
                    tParent.endChange();
            }
        }
        this.mElementsDeleted = false;
        this.mApp.viewer.requestRenderFrame();
    }
}
export class DeleteElements extends AbstractInsertDeleteElements {
    constructor(pApp, pElements) {
        super(pApp, pElements);
    }
    execute(pParameter) {
        return (this.redo().then(() => { return (true); }));
    }
    undo() {
        this.insertElements(true);
        return (Promise.resolve());
    }
    redo() {
        this.deleteElements();
        return (Promise.resolve());
    }
}
export class InsertElements extends AbstractInsertDeleteElements {
    constructor(pApp, pElements) {
        super(pApp, pElements);
    }
    execute(pParameter) {
        this.insertElements(false); //nodes should already be part of the scene
        return (Promise.resolve(true));
    }
    undo() {
        this.deleteElements();
        return (Promise.resolve());
    }
    redo() {
        this.insertElements(true);
        return (Promise.resolve());
    }
}

==> pCon.configurator_Online_W-CF_9.0.0.tgz: package/modules/core/cmd/InsertDeleteElements.js <==
import { clone } from "../../utils/array";
import { UndoOperation } from "../mdl/SceneElement";
import { AbstractCommand } from "./AbstractCommand";
export class AbstractInsertDeleteElements extends AbstractCommand {
    constructor(pApp, pElements) {
        super(pApp);
        this.mElements = clone(pElements);
        this.mElementsDeleted = false;
        //store element and node parents
        this.mElementParents = [];
        this.mElementUndoData = [];
        this.mNodeParents = [];
        for (const tElement of this.mElements) {
            this.mElementParents.push(tElement.getParentElement());
            this.mElementUndoData.push(null);
            this.mNodeParents.push(tElement.node.parent);
        }
    }
    isAvailable() {
        return (this.mElements != null);
    }
    isUndoable() {
        return (true);
    }
    dispose() {
        if (this.mElementsDeleted) {
            for (const tElement of this.mElements)
                tElement.dispose();
        }
        this.mElements = undefined;
    }
    deleteElements() {
        const tModel = this.mApp.model;
        try {
            tModel.beginSelectionChange();
            //get delete undo data
            for (let i = 0; i < this.mElements.length; ++i) {
                this.mElementUndoData[i] = this.mElements[i].saveUndoData(UndoOperation.Delete);
            }
            //start change section for parents
            for (let i = 0; i < this.mElementParents.length; ++i) {
                const tParent = this.mElementParents[i];
                if (tParent != null)
                    tParent.beginChange();
            }
            for (let i = 0; i < this.mElements.length; ++i) {
                tModel.removeElement(this.mElements[i], true, false);
            }
        }
        finally {
            //end change section for parents
            for (let i = 0; i < this.mElementParents.length; ++i) {
                const tParent = this.mElementParents[i];
                if (tParent != null)
                    tParent.endChange();
            }
            tModel.endSelectionChange();
        }
        this.mElementsDeleted = true;
        this.mApp.viewer.requestRenderFrame();
    }
    insertElements(pAddToScene) {
        const tModel = this.mApp.model;
        try {
            //start change section for parents
            for (let i = 0; i < this.mElementParents.length; ++i) {
                const tParent = this.mElementParents[i];
                if (tParent != null)
                    tParent.beginChange();
            }
            for (let i = 0; i < this.mElements.length; ++i) {
                tModel.addElement(this.mElements[i], this.mNodeParents[i], pAddToScene);
            }
            //load delete undo data
            for (let i = 0; i < this.mElements.length; ++i) {
                if (this.mElementUndoData[i] != null)
                    this.mElements[i].loadUndoData(UndoOperation.Delete, this.mElementUndoData[i]);
            }
        }
        finally {
            //end change section for parents
            for (let i = 0; i < this.mElementParents.length; ++i) {
                const tParent = this.mElementParents[i];
                if (tParent != null)
                    tParent.endChange();
            }
        }
        this.mElementsDeleted = false;
        this.mApp.viewer.requestRenderFrame();
    }
}
export class DeleteElements extends AbstractInsertDeleteElements {
    constructor(pApp, pElements) {
        super(pApp, pElements);
    }
    execute(pParameter) {
        return (this.redo().then(() => { return (true); }));
    }
    undo() {
        this.insertElements(true);
        return (Promise.resolve());
    }
    redo() {
        this.deleteElements();
        return (Promise.resolve());
    }
}
export class InsertElements extends AbstractInsertDeleteElements {
    constructor(pApp, pElements) {
        super(pApp, pElements);
    }
    execute(pParameter) {
        this.insertElements(false); //nodes should already be part of the scene
        return (Promise.resolve(true));
    }
    undo() {
        this.deleteElements();
        return (Promise.resolve());
    }
    redo() {
        this.insertElements(true);
        return (Promise.resolve());
    }
}
